summaryrefslogtreecommitdiff
path: root/include/objects.h
diff options
context:
space:
mode:
authorcoco875 <59367621+coco875@users.noreply.github.com>2023-12-25 14:43:47 +0100
committerGitHub <noreply@github.com>2023-12-25 06:43:47 -0700
commit3638f19145086cfc494d9d506a032e4781b166b7 (patch)
tree0d3476144896750b07f18b308feaafe624fd8566 /include/objects.h
parent371516f918c0d3a3995f30b71b28c7703a0ec3cd (diff)
some rename in code_8006e9c0 (#512)
* some basic function renames * Renaming player hud related variables.
Diffstat (limited to 'include/objects.h')
-rw-r--r--include/objects.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/include/objects.h b/include/objects.h
index 328c52841..03995fa79 100644
--- a/include/objects.h
+++ b/include/objects.h
@@ -175,10 +175,10 @@ extern s32 D_80183DB8[];
// Appears to be a list of object list indices for the Item Window part of the HUD
extern s32 gItemWindowObjectByPlayerId[];
-// Used for loop bounds when accessing D_80183EA0
+// Used for loop bounds when accessing indexObjectList1
extern s16 D_80165750;
// These seem to be limits on different object types in Moo Moo Farm
-// See func_80070780 in code_8006E9C0.c
+// See init_course_object in code_8006E9C0.c
// Maybe max number of active moles in a given group of moles?
extern s32 D_8018D1C8;
extern s32 D_8018D1D0;
@@ -189,9 +189,9 @@ extern s32 D_8018D3C0;
extern Collision D_8018C0B0[];
/**
* D_80183EA0, D_80183F28, D_8018BFA8, and D_8018C030 are all lists of indices in gObjectList.
* func_80070190 initializes them in such a way that the indicies in each list are not adjacent.
* First D_80183EA0 gets an unused index, then D_80183F28, then D_8018BFA8, then D_8018C030, and then it loops.
*
* The objects found at the indices in each list appears to be course dependent
**/
@@ -250,7 +250,7 @@ extern s16 gNumActiveThwomps;
* Penguins in Sherbet Land?
* Flag Poles in Yoshi Valley?
**/
-extern s32 D_80183EA0[];
+extern s32 indexObjectList1[];
#define NUM_SEAGULLS 10
@@ -280,7 +280,7 @@ extern Vec3s gHedgehogPatrolPoints[];
* Hedgehogs in Yoshi Valley?
* Spawn for big fire breath in Bowser's Castle
**/
-extern s32 D_80183F28[];
+extern s32 indexObjectList2[];
#define NUM_BOOS 0xA
#define NUM_FIRE_BREATHS 4
@@ -291,10 +291,12 @@ extern Vec3s gFireBreathsSpawns[];
* Boos in Banshee Boardwalk
* Spawners for the 4 small fire breaths inside Bowser's Castle
**/
-extern s32 D_8018BFA8[];
+extern s32 indexObjectList3[];
-// Appears to go entirely unused?
-extern s32 D_8018C030[];
+/**
+ * Unused list of object indices
+*/
+extern s32 indexObjectList4[];
#define D_8018C1B0_SIZE 128
#define NUM_MAX_MOLES 0x1F
@@ -189,9 +189,9 @@ extern s32 D_8018D3C0;
extern Collision D_8018C0B0[];
/**
- * D_80183EA0, D_80183F28, D_8018BFA8, and D_8018C030 are all lists of indices in gObjectList.
- * func_80070190 initializes them in such a way that the indicies in each list are not adjacent.
- * First D_80183EA0 gets an unused index, then D_80183F28, then D_8018BFA8, then D_8018C030, and then it loops.
+ * indexObjectList1, indexObjectList2, indexObjectList3, and indexObjectList4 are all lists of indices in gObjectList.
+ * init_object_list_index initializes them in such a way that the indicies in each list are not adjacent.
+ * First indexObjectList1 gets an unused index, then indexObjectList2, then indexObjectList3, then indexObjectList4, and then it loops.
*
* The objects found at the indices in each list appears to be course dependent